@@ -1,5 +1,5 @@
 package Net::HTTP::Methods;
-$Net::HTTP::Methods::VERSION = '6.17';
+our $VERSION = '6.22';
 use strict;
 use warnings;
 use URI;
@@ -35,8 +35,14 @@ sub http_configure {
     die "Listen option not allowed" if $cnf->{Listen};
     my $explicit_host = (exists $cnf->{Host});
     my $host = delete $cnf->{Host};
-    my $peer = $cnf->{PeerAddr} || $cnf->{PeerHost};
-    if (!$peer) {
+    # All this because $cnf->{PeerAddr} = 0 is actually valid.
+    my $peer;
+    for my $key (qw{PeerAddr PeerHost}) {
+	next if !defined($cnf->{$key}) || q{} eq $cnf->{$key};
+	$peer = $cnf->{$key};
+	last;
+    }
+    if (!defined $peer) {
 	die "No Host option provided" unless $host;
 	$cnf->{PeerAddr} = $peer = $host;
     }
@@ -649,7 +655,7 @@ Net::HTTP::Methods - Methods shared by Net::HTTP and Net::HTTPS
 
 =head1 VERSION
 
-version 6.17
+version 6.22
 
 =head1 AUTHOR
 
@@ -657,7 +663,7 @@ Gisle Aas <gisle@activestate.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2001-2017 by Gisle Aas.
+This software is copyright (c) 2001 by Gisle Aas.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
